.wp-block-rank-math-toc-block {
	nav {
		ol {
			counter-reset: item;

			li {
				display: block;
			}

			li:before {
				content: counters(item, ".") ". ";
				counter-increment: item;
			}
		}

	}
}
